@@ -5,7 +5,7 @@ use App::SimulateReads::Base 'class';
 
 extends 'App::SimulateReads::CLI';
 
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 override 'opt_spec' => sub {
 	super
@@ -26,7 +26,7 @@ sub execute {
 sub fill_opts {
 	my ($self, $opts, $default_opt) = @_;
 	if (ref $opts ne 'HASH' || ref $default_opt ne 'HASH') {
-		croak '$opts and $default_opt need to be a hash reference';
+		die '$opts and $default_opt need to be a hash reference';
 	}
 
 	for my $opt (keys %$default_opt) {
@@ -46,7 +46,7 @@ App::SimulateReads::CLI::Command - App::SimulateReads::CLI subclass for commands
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
