@@ -6,7 +6,7 @@ use Math::Random 'random_normal';
 
 extends 'App::SimulateReads::Read';
 
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 use constant {
 	NUM_TRIES => 1000
@@ -27,7 +27,7 @@ has 'fragment_stdd' => (
 sub BUILD {
 	my $self = shift;
 	unless (($self->fragment_mean - $self->fragment_stdd) >= $self->read_size) {
-		croak sprintf "fragment_mean (%d) minus fragment_stdd (%d) must be greater or equal to read_size (%d)\n"
+		die sprintf "fragment_mean (%d) minus fragment_stdd (%d) must be greater or equal to read_size (%d)\n"
 			=> $self->fragment_mean,  $self->fragment_stdd, $self->read_size;
 	}
 }
@@ -36,7 +36,7 @@ sub gen_read {
 	my ($self, $seq_ref, $seq_size, $is_leader) = @_;
 
 	if ($seq_size < $self->fragment_mean) {
-		croak sprintf "seq_size (%d) must be greater or equal to fragment_mean (%d)\n"
+		die sprintf "seq_size (%d) must be greater or equal to fragment_mean (%d)\n"
 			=> $seq_size, $self->fragment_mean;
 	}
 
@@ -48,7 +48,7 @@ sub gen_read {
 		# fragment_size must be greater or equal to read_size
 		# As fragment_size is randomly calculated, try out NUM_TRIES times
 		if (++$random_tries > NUM_TRIES) {
-			croak sprintf
+			die sprintf
 				"So many tries to calculate a fragment. the constraints were not met:\n" .
 				"fragment_size <= seq_size (%d) and fragment_size >= read_size (%d)\n"
 					=> $seq_size, $self->read_size;
@@ -90,7 +90,7 @@ App::SimulateReads::Read::PairedEnd - App::SimulateReads::Read subclass for simu
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 AUTHOR
 
